@@ -1,6 +1,6 @@
 /* bsjson.c - Simple JSON implementation
  *
- * Copyright (C) 2014, Borislav Sapundzhiev
+ * Copyright (C) 2014-2017, Borislav Sapundzhiev
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -79,8 +79,8 @@ JsonNode * JsonNode_Create()
     node->m_type = JSON_ROOT;
     node->m_name = NULL;
     node->m_parent = NULL;
-    node->m_pairs = cpo_array_create(4 , sizeof(JsonPair));
-    node->m_childs = cpo_array_create(4 , sizeof(JsonNode));
+    node->m_pairs = cpo_array_create(4, sizeof(JsonPair));
+    node->m_childs = cpo_array_create(4, sizeof(JsonNode));
     return node;
 }
 
@@ -90,8 +90,8 @@ JsonNode * JsonNode_createChild(JsonNode * node, String name, int type)
     child->m_type = type;
     child->m_parent = node;
     child->m_name = (name != NULL) ? strdup(name) : NULL;
-    child->m_pairs = cpo_array_create(4 , sizeof(JsonPair));
-    child->m_childs = cpo_array_create(4 , sizeof(JsonNode));
+    child->m_pairs = cpo_array_create(4, sizeof(JsonPair));
+    child->m_childs = cpo_array_create(4, sizeof(JsonNode));
     return child;
 }
 
@@ -164,29 +164,29 @@ JsonNode * JsonNode_findChild(JsonNode *node, const String name, int type)
     return ret;
 }
 
-int JsonNode_getChildCount(JsonNode *node)
+asize_t JsonNode_getChildCount(JsonNode *node)
 {
     return node->m_childs->num;
 }
 
-int JsonNode_getPairCount(JsonNode *node)
+asize_t JsonNode_getPairCount(JsonNode *node)
 {
     return node->m_pairs->num;
 }
 
-JsonNode * JsonNode_getChild(JsonNode *node, int index)
+JsonNode * JsonNode_getChild(JsonNode *node, asize_t index)
 {
     return (JsonNode *)cpo_array_get_at(node->m_childs, index);
 }
 
-JsonPair * JsonNode_getPair(JsonNode *node, int index)
+JsonPair * JsonNode_getPair(JsonNode *node, asize_t index)
 {
     return (JsonPair *)cpo_array_get_at(node->m_pairs, index);
 }
 
 void JsonNode_delete(JsonNode *node)
 {
-    int i;
+    asize_t i;
     if (!node) return;
     for (i=0; i < JsonNode_getPairCount(node); i++) {
         JsonPair *pair = JsonNode_getPair(node, i);
@@ -208,7 +208,7 @@ void JsonNode_delete(JsonNode *node)
 
 void JsonNode_deleteTree(JsonNode *root)
 {
-    int i;
+    asize_t i;
     if (!root) return;
     for (i=0 ; i < JsonNode_getChildCount(root); i++) {
         JsonNode *node = JsonNode_getChild(root, i);
@@ -219,13 +219,12 @@ void JsonNode_deleteTree(JsonNode *root)
 
     if (root->m_type == JSON_ROOT) {
         free(root);
-        root = NULL;
     }
 }
 /* return allocated UT_string */
 static UT_string *JsonNode_getJSON_UT(JsonNode *node, String last)
 {
-    int i, nPairs, nChilds;
+    asize_t i, nPairs, nChilds;
     UT_string *buff;
     utstring_new(buff);
     if (buff == NULL) return NULL;
@@ -379,7 +378,7 @@ static int JsonParser_internalData(struct ParserInternal *pi)
     return 0;
 }
 
-static char JsonParser_next_char(const char *p , int pos)
+static char JsonParser_next_char(const char *p, int pos)
 {
     char ch;
     while ( (ch = *(p+ ++pos)) != '\0' ) {
@@ -390,7 +389,7 @@ static char JsonParser_next_char(const char *p , int pos)
     return ch;
 }
 
-static char JsonParser_prev_char(const char *p , int pos)
+static char JsonParser_prev_char(const char *p, int pos)
 {
     char ch;
     while ( (ch = *(p+ --pos)) != '\0' ) {
@@ -415,14 +414,14 @@ static char JsonParser_prev_char(const char *p , int pos)
     (JsonParser_peek_char(p,pos) == Json_elem(JSON_CR)\
     || JsonParser_peek_char(p, pos) == Json_elem(JSON_LF))
 
-static int JsonParser_internalParse(struct ParserInternal *pi, const char* json , int len)
+static int JsonParser_internalParse(struct ParserInternal *pi, const char* json, int len)
 {
     int i;
-    char ch;
     enum eElemType elemType;
     const char *p = json;
 
     for (i =0; i < len + 1; i++) {
+        char ch;
 
         if(pi->error != JSON_ERR_NONE) break;
 
@@ -520,7 +519,7 @@ static void JsonParser_startElem(struct JsonParser *parser, const String name, i
     void *ptr = NULL;
     JsonNode* parent= NULL, *node=NULL;
 
-    DEBUG_PRINT("Json_startElem %s type %d\n", name ,type );
+    DEBUG_PRINT("Json_startElem %s type %d\n", name, type );
 
     if (parser->m_nodeStack->num > 0) {
         ptr = stack_back(parser->m_nodeStack);
@@ -544,7 +543,7 @@ static void JsonParser_startElem(struct JsonParser *parser, const String name, i
 
 static void JsonParser_endElem(struct JsonParser *parser, const String name, int type )
 {
-    DEBUG_PRINT("Json_endElem %s type %d\n", name ,type );
+    DEBUG_PRINT("Json_endElem %s type %d\n", name, type );
     assert( parser->m_nodeStack->num > 0 );
     if (parser->m_nodeStack->num > 0) {
         stack_pop_back(parser->m_nodeStack);
@@ -586,7 +585,7 @@ JsonNode * JsonParser_parse(struct JsonParser *parser, const char * json)
     pi.startElem = JsonParser_startElem;
     pi.endElem = JsonParser_endElem;
     pi.elemData = JsonParser_elemData;
-    parser->m_nodeStack = cpo_array_create(JSON_STACK_SIZE , sizeof(void*));
+    parser->m_nodeStack = cpo_array_create(JSON_STACK_SIZE, sizeof(void*));
     if (JsonParser_internalParse(&pi, json, (int)strlen(json)) == JSON_ERR_NONE) {
         root = parser->m_root;
     } else {
@@ -605,32 +604,32 @@ JsonNode * JsonParser_parse(struct JsonParser *parser, const char * json)
 static void JsonParser_stripCommentsFromBuffer(char *buff, long size)
 {
     long i;
-    for(i = 0; i < size; i++) {
-        if(((i < size - 1) && buff[i] == '/' && buff[i+1] == '/') || buff[i] == '#' || buff[i] == '"') {
-            char s = buff[i];
-            long j = i;
-            do {
-                if(s != '"') {
-                    buff[i] = ' ';
-                }
-                else if (i > j && buff[i] == '"') {
-                    i++;
-                    break;
-                }
+    unsigned char is_string = 0;
+
+    for (i = 0; i < size; i++) {
+        if (buff[i] == Json_elem(JSON_QUOTE))
+            is_string = !is_string;
+        if (is_string)
+            continue;
+        /* strip // and # comments */
+        if ((buff[i] == '/' && buff[i+1] == '/') || buff[i] == '#') {
+            while(buff[i] != '\n' && buff[i] != 0) {
+                buff[i] = ' ';
                 i++;
-            } while(buff[i] != '\n' && buff[i] != 0);
+            }
         }
     }
 }
 
 JsonNode * JsonParser_parseFile(struct JsonParser *parser, const char * fileName)
 {
-    char * buffer = 0;
-    long length = 0, read = 0;
     JsonNode * root = NULL;
     FILE *f = fopen (fileName, "rb");
 
     if (f != NULL) {
+        char * buffer;
+        long length;
+        size_t read = 0;
         fseek (f, 0, SEEK_END);
         length = ftell (f);
         fseek (f, 0, SEEK_SET);
